@@ -10,7 +10,7 @@ __docformat__ = "restructuredtext"
 
 # module level doc-string
 __doc__ = """
-golog - a powerful general logging library for Python
+golog - a powerful general logging and monitoring library for Python
 =====================================================================
 
 *golog* is a Python package providing many different useful functions
@@ -18,6 +18,8 @@ golog - a powerful general logging library for Python
 Main Features
 -------------
 Here are just a few of the things that iago does well:
-
-  - TODO
+  - Nice Logging
+  - Integrated Alerts (Slack, Email , SMS)
+  - Useful Decorators
+  - Tools to make your code nicer and more reliable
 """
